Fixed dead pointer problem when handling interfaces
[lcr.git] / gsm.h
diff --git a/gsm.h b/gsm.h
index 254797e..724a4c2 100644 (file)
--- a/gsm.h
+++ b/gsm.h
@@ -15,7 +15,7 @@ enum {
 };
 
 struct lcr_gsm {
-       struct interface *interface;    /* interface this instance is associated to */
+       char interface_name[64]; /* name of interface this instance is associated to */
        struct lcr_gsm  *gsm_ms_next;   /* list of MS instances, in case of MS */
        char            name[16];       /* name of MS instance, in case of MS */
        int             type;           /* LCR_GSM_TYPE_*/